@@ -14,7 +14,7 @@ g_depth = 0
 def ZPadding(size):
     return Const(bytes(size), Bytes(size))
 
-def recusive_reload(obj, token=None):
+def recursive_reload(obj, token=None):
     global g_depth
 
     if token is None:
@@ -36,7 +36,7 @@ def recusive_reload(obj, token=None):
                 obj.subcon = obj.subcon._reloadcls(token=token)
         else:
             if isinstance(obj.subcon, Construct):
-                recusive_reload(obj.subcon, token)
+                recursive_reload(obj.subcon, token)
     if isinstance(obj, Construct) and hasattr(obj, 'subcons'):
         # Construct types that have lists
         new_subcons = []
@@ -47,7 +47,7 @@ def recusive_reload(obj, token=None):
                     item = item._reloadcls()
             else:
                 if isinstance(item, Construct):
-                    recusive_reload(item, token)
+                    recursive_reload(item, token)
             new_subcons.append(item)
             obj.subcons = new_subcons
 
@@ -60,7 +60,7 @@ def recusive_reload(obj, token=None):
                     obj.cases[i] = item._reloadcls(token=token)
             else:
                 if isinstance(item, Construct):
-                    recusive_reload(item, token)
+                    recursive_reload(item, token)
 
     for field in dir(obj):
         value = getattr(obj, field)
@@ -70,7 +70,7 @@ def recusive_reload(obj, token=None):
                 setattr(obj, field, value._reloadcls(token=token))
         else:
             if isinstance(value, Construct):
-                recusive_reload(value, token)
+                recursive_reload(value, token)
 
     obj._token = token
 
@@ -140,7 +140,7 @@ class ConstructClassException(Exception):
     pass
 
 
-# We need to inherrit Construct as a metaclass so things like If and Select will work
+# We need to inherit Construct as a metaclass so things like If and Select will work
 class ReloadableConstructMeta(ReloadableMeta, Construct):
 
     def __new__(cls, name, bases, attrs):
@@ -187,9 +187,9 @@ class ReloadableConstructMeta(ReloadableMeta, Construct):
         return cls
 
 class ConstructClassBase(Reloadable, metaclass=ReloadableConstructMeta):
-    """ Offers two benifits over regular construct
+    """ Offers two benefits over regular construct
 
-        1. It's reloadable, and can recusrivly reload other refrenced ConstructClasses
+        1. It's reloadable, and can recursively reload other referenced ConstructClasses
         2. It's a class, so you can define methods
 
         Currently only supports parsing, but could be extended to support building
@@ -276,7 +276,7 @@ class ConstructClassBase(Reloadable, metaclass=ReloadableConstructMeta):
         #print(f"_reloadcls({cls})", id(cls))
         newcls = Reloadable._reloadcls.__func__(cls, force)
         if hasattr(newcls, "subcon"):
-            recusive_reload(newcls.subcon, token)
+            recursive_reload(newcls.subcon, token)
         return newcls
 
     def _apply(self, obj):
@@ -386,9 +386,9 @@ class ROPointer(Pointer):
         return Pointer._parse(self, stream, context, path)
 
 class ConstructClass(ConstructClassBase, Container):
-    """ Offers two benifits over regular construct
+    """ Offers two benefits over regular construct
 
-        1. It's reloadable, and can recusrivly reload other refrenced ConstructClasses
+        1. It's reloadable, and can recursively reload other referenced ConstructClasses
         2. It's a class, so you can define methods
 
         Currently only supports parsing, but could be extended to support building
