@@ -195,12 +195,10 @@ const struct dart_params dart_t8110 = {
 
 dart_dev_t *dart_init(uintptr_t base, u8 device, bool keep_pts, enum dart_type_t type)
 {
-    dart_dev_t *dart = malloc(sizeof(*dart));
+    dart_dev_t *dart = calloc(1, sizeof(*dart));
     if (!dart)
         return NULL;
 
-    memset(dart, 0, sizeof(*dart));
-
     dart->regs = base;
     dart->device = device;
     dart->type = type;
